pypaginate.adapters.sqlalchemy.types
====================================

.. py:module:: pypaginate.adapters.sqlalchemy.types

.. autoapi-nested-parse::

   Type aliases for SQLAlchemy adapter.

   Centralizes SQLAlchemy type imports behind TYPE_CHECKING
   to keep the adapter importable without SQLAlchemy installed.



Attributes
----------

.. autoapisummary::

   pypaginate.adapters.sqlalchemy.types.SelectStatement


Module Contents
---------------

.. py:data:: SelectStatement

